@@ -1,11 +1,9 @@
 //! Code generator modules
 
-
-
-
-
 mod cargo_crate;
+mod features;
 mod include_file;
 
 pub(crate) use self::cargo_crate::CargoCrateGenerator;
+pub(crate) use self::features::FeaturesGenerator;
 pub(crate) use self::include_file::IncludeFileGenerator;
